@@ -1,4 +1,5 @@
 from typing import List, Union, Dict
+
 from .type_classes import *
 from .page import *
 
@@ -127,6 +128,20 @@ def read_file(message: str, button_text: str = 'Next', initial_value: str = '',
     '''
     return get_single_value(Page().read_file(message, initial_value, required, hint=hint).run(button_text))
 
+def read_image(message: str, button_text: str = 'Next', initial_value: str = '', required: Union[bool, str] = True, hint: str = None) -> FileResponse:
+    '''Read a image file value from the user
+
+    Args:
+        message (str): The message to display to the user
+        button_text (str): The text to display on the button that will submit the value
+        initial_value (str): The initial value to display to the user
+        required (bool or str): Whether the input is required or not eg. "this field is required"
+
+    Returns:
+        FileResponse: The image file uploaded by the user the user
+    '''
+    return get_single_value(Page().read_image(message, initial_value, required, hint=hint).run(button_text))
+
 
 def read_dropdown(message: str, options: Union[List[str], List[Dict]], multiple: bool = False, button_text: str = 'Next', initial_value = None, placeholder: str = "Choose your option", required: Union[bool, str] = True, hint: str = None) -> Union[str, List[str]]:
     '''Read a dropdown value from the user
@@ -163,7 +178,7 @@ def read_multiple_choice(message: str, options: Union[List[str], List[Dict]], mu
     return get_single_value(Page().read_multiple_choice(message, options, multiple, initial_value, required, hint=hint).run(button_text))
 
 
-def read_list(item_schema, button_text: str = 'Next', initial_value=[{}], hint: str = None):
+def read_list(item_schema, button_text: str = 'Next', initial_value=[{}], min: int = None, max: int = None, hint: str = None):
     '''Read a list value from the user
 
     Args:
@@ -173,7 +188,7 @@ def read_list(item_schema, button_text: str = 'Next', initial_value=[{}], hint:
     Returns:
         list: The values entered by the user
     '''
-    return get_single_value(Page().read_list(item_schema, initial_value=initial_value, hint=hint).run(button_text))
+    return get_single_value(Page().read_list(item_schema, initial_value=initial_value,min=min, max=max, hint=hint).run(button_text))
 
 
 def read_cards(label: str, options: List[Dict], multiple: bool = False, button_text: str = 'Next', initial_value: Union[Union[str, float], List[Union[str, float]]] = None, required: Union[bool, str] = True, hint: str = None):
